<div align="center"><img src="https://github.com/yinsn/FlowFunnel/blob/develop/docs/images/flowfunnel-logo.svg" width="800"/></div>

# FlowFunnel

Leveraging Bayesian hierarchical models to diagnose issues and proactively predict user flow stages in conversion funnels. A cutting-edge solution for optimizing user behavior in digital platforms.
